Index: trunk/ppSim/src/ppSimPhotomReadoutFake.c
===================================================================
--- trunk/ppSim/src/ppSimPhotomReadoutFake.c	(revision 21183)
+++ trunk/ppSim/src/ppSimPhotomReadoutFake.c	(revision 21365)
@@ -12,5 +12,5 @@
     }
 
-# if 0    
+# if 0
     // set the photcode for this image
     if (!psphotAddPhotcode (recipe, config, view, "PPSIM.FAKE.CHIP")) {
@@ -22,5 +22,5 @@
     // *** in this section, perform the photometry for real + fake sources on PPSIM.FAKE.CHIP ***
 
-    // find the currently selected readout. 
+    // find the currently selected readout.
     // we always perform photometry on the mosaiced chip
     pmReadout  *readout = pmFPAfileThisReadout (config->files, view, "PPSIM.FAKE.CHIP");
@@ -35,6 +35,6 @@
     PS_ASSERT_PTR_NON_NULL (injectedSources, false);
 
-    // Generate the mask and weight images, including the user-defined analysis region of interest
-    psphotSetMaskAndWeight (config, readout, recipe);
+    // Generate the mask and variance images, including the user-defined analysis region of interest
+    psphotSetMaskAndVariance (config, readout, recipe);
 
     // XXX need to define the source pixels
@@ -53,13 +53,13 @@
     psArray *realSources = psArrayAlloc (realMeasuredSources->n);
     for (int i = 0; i < realMeasuredSources->n; i++) {
-	realSources->data[i] = pmSourceCopy (realMeasuredSources->data[i]);
+        realSources->data[i] = pmSourceCopy (realMeasuredSources->data[i]);
     }
 
     // load the psf model, if suppled.  FWHM_X,FWHM_Y,etc are saved in the recipe
-    // this function uses PSPHOT.PSF.LOAD as the pmFPAfile 
+    // this function uses PSPHOT.PSF.LOAD as the pmFPAfile
     pmPSF *psf = psphotLoadPSF (config, view, recipe);
     assert (psf);
 
-    // remove all sources 
+    // remove all sources
     psphotRemoveAllSources (realSources, recipe);
 
@@ -76,5 +76,5 @@
 
     // XXX fake sources should measure peak->x,y, force sources should not
-    psImageMaskType maskVal = 0xff; 
+    psImageMaskType maskVal = 0xff;
     psImage *significance = psphotSignificanceImage (readout, recipe, 1, maskVal);
     ppSimDetections (significance, recipe, fakeSources);
@@ -90,5 +90,5 @@
     psphotGuessModels (config, readout, realSources, psf);
     psphotGuessModels (config, readout, fakeSources, psf);
-    
+
     // linear fit to real + fake sources
     psArray *sources = ppSimMergeSources (realSources, fakeSources);
@@ -113,6 +113,6 @@
     pmReadout *fakeReadout = pmFPAfileThisReadout (config->files, view, "PPSIM.FAKE.SOURCES");
     if (!fakeReadout) {
-	fakeReadout = pmReadoutAlloc (fakeCell);
-	psFree (fakeReadout); // there is a copy on 'cell' as well
+        fakeReadout = pmReadoutAlloc (fakeCell);
+        psFree (fakeReadout); // there is a copy on 'cell' as well
     }
     psAssert (fakeReadout, "no fakeReadout?");
